---
title: "The IT Environment for Students"
date: "2024-2025"
colorlinks: true
header-includes:
- |
  ```{=latex}
  \usepackage{awesomebox}

  \usepackage{xcolor}

  \definecolor{ensae-red}{RGB}{172, 1, 42}
  \setkomafont{section}{\LARGE\color{ensae-red}}
  \setkomafont{subsection}{\Large\color{ensae-red}}

  ```
pandoc-latex-environment:
  noteblock: [info]
  tipblock: [tip]
  warningblock: [warning]
  cautionblock: [caution]
  importantblock: [important]
...

The National School of Statistics and Economic Administration (ENSAE) offers a rich and diverse IT environment to support students throughout their education. This environment includes computer accounts, email boxes, office suites, scientific software, and access to these resources both in the school building and via the internet.

!!! info
    **The Department of Information Systems and Telecommunications provides assistance and support to all users of IT resources. You can contact them:**
    
    * **by email at [support@ensae.fr](mailto://support@ensae.fr)**
    * **by opening a ticket on [the support portal | assistance.ensae.fr](https://assistance.ensae.fr)**
    * **by phone at 01.70.26.67.67**
    * **in person at office 3082 (3rd floor of ENSAE)**


## The ENSAE Computer Account

### Your username and password

Upon registration, you will receive an ENSAE account, which is the primary identifier for accessing the school's various IT resources. This account is used to log into school computers, access online services, and authenticate on different platforms.

The account username is generally in the form:

```
<first letter of first name + last name>
```

In some cases, particularly for the use of external services (Office 365, eduroam, etc.), your username will have the suffix `@ensae.fr`.

The password associated with this account must comply with the following security rules:

!!! info
    * Minimum 12 characters
    * Must not contain the user's account name or parts of the user's full name that exceed two consecutive characters
    * Must contain characters from three of the following four categories:
        * Uppercase characters (A to Z)
        * Lowercase characters (a to z)
        * Digits (0 to 9)
        * Non-alphabetic characters (for example, !, $, #, %)


!!! warning "Attention"
    The ENSAE computer account is strictly personal and should never be shared with others. If you suspect your password has been stolen, please notify us immediately

The password associated with your ENSAE account can be changed from the [account management service | https://auth.groupe-genes.fr/realms/ensae/account/](https://auth.groupe-genes.fr/realms/ensae/account/#/).

### The ENSAE email box

Every ENSAE student has an email address in the form `firstname.lastname@ensae.fr`.

!!! info
    In case of homonymy, this email address may take a different form

This mailbox is accessible from the internet at [https://messagerie.ensae.fr/](https://messagerie.ensae.fr/) using your ENSAE account.

This mailbox has a maximum space of **3 GB** of data beyond which it is no longer possible to receive or send emails.

### Personal storage space

Each student has a personal storage space of 10GB accessible from all computer workstations in the building, but also from the internet at:

[https://mesdossiers.ensae.fr](https://mesdossiers.ensae.fr).


## IT resources provided

!!! info
    An intranet space is available to all students at:
    
    [https://genes.sharepoint.com/sites/intraensae](https://genes.sharepoint.com/sites/intraensae).
    
    You will find all the information about life at school there.

### Pamplemousse Application

The Pamplemousse application allows all students to follow their education at ENSAE, it is available on the internet at:

[https://pamplemousse.ensae.fr](https://pamplemousse.ensae.fr)

### IP-Paris Campus mobile application

A mobile application is available for Android and Apple phones under the name **IP-Paris Campus**. It provides access to various services directly from your smartphone:

* Campus map
* Schedule
* Directory

### Computer workstations

ENSAE provides students with several computer rooms equipped with workstations on the 2nd floor of the building. These computers are accessible with the ENSAE account and allow access to all the data in your personal storage. Each workstation is pre-configured with necessary software such as R, Python, SAS, Stata, Matlab....

Outside of class hours, some computer rooms are also available for open access (rooms 2008 and 2015). Students can freely access them for their personal work, research, or group projects.

### Software

ENSAE offers you a set of software with specific licenses on the workstations in the building, but also, for some, installable on personal computers such as SAS, Matlab, Mathematica...

More details are available at the following link: [https://genes.sharepoint.com/sites/intraensae/SitePages/Logiciels.aspx](https://genes.sharepoint.com/sites/intraensae/SitePages/Logiciels.aspx)

### Printing

ENSAE students have access to 3 copier printers (room 2010 and library).

!!! warning "Attention"
    The ENSAE Student account does not allow color printing.

Printing can be initiated:

* from PCs in the building
* from the service https://print.ensae.fr
* by sending an email with attachment to print@ensae.fr

The printing is released using the access card. For first use, you must first associate the student badges with the computer accounts by following the procedure displayed above the copiers.

Every student has a credit of 2€ renewed every month, and cumulative up to 6€.

!!! info
    * Currently, the monthly amount corresponds to approximately 200 B&W pages.
    * If the credit is expired, it will no longer be possible to print, there is no possibility of payment.

You can view your prints via the following link:

[https://print.ensae.fr/user](https://print.ensae.fr/user)
    
### Datalab

Students have a personal space on the GENES datalab accessible at [https://onyxia.lab.groupe-genes.fr](https://onyxia.lab.groupe-genes.fr)

This service allows, with your ENSAE account, to launch different interactive services (such as Rstudio, Jupyter-Python, vscode...), but also database services or automation.

To learn more -> [https://documentation-dsit.lab.groupe-genes.fr/Services/Datalab/Onyxia/](https://documentation-dsit.lab.groupe-genes.fr/Services/Datalab/Onyxia/)

!!! info
    Each individual account allows launching a maximum of 5 services, totaling:
    
    * 5 CPU
    * 1 GPU
    * 50 GB of RAM
    * 100 GB of storage

### Wi-Fi

The ENSAE building has several Wi-Fi networks allowing internet access. Students can use the following Wi-Fi networks:

* **ENSAE**: usable with the ENSAE account identifier and your password, it allows access to some internal ENSAE resources and notably benefits from direct access to the library's electronic resources without having to authenticate with publishers.
* **Eduroam**: The EDUROAM service offers secure wireless access to the Internet for staff and students of the higher education/research community during their travels. It can be used with your identifier (**with the suffix @ensae.fr**) and your password.


### Microsoft Software

Your ENSAE account allows you to have access to Microsoft 365 and Office suites (Word, Excel, PowerPoint...) at the following URL [https://portal.office.com/account/](https://portal.office.com/account/)

!!! info
    Access to Microsoft cloud is done with the identifier `<identifier>@ensae.fr` and the password of your ENSAE account.

### Other services

The ENSAE computer account allows access to other services that are not directly managed by the GENES Department of Information Systems and Telecommunications.
The GIP RENATER thus provides several services accessible to all students such as an event planning tool (https://evento.renater.fr/)
Your computer account also allows you to remotely access most of the electronic resources of the school library, thanks to a connection via the institution (ENSAE or GENES).


### Various requests

The Department of Information Systems and Telecommunications remains attentive to various requests related to the IT environment offered to students.

!!! Important
    Do not hesitate to open tickets on [https://assistance.ensae.fr](https://assistance.ensae.fr) for any requests on IT services
